==> mozc_0.12.410.102.orig.tar.gz: mozc-0.12.410.102/gui/dictionary_tool/dictionary_tool_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.ui" line="14"/>
        <source>Mozc Dictionary Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.ui" line="31"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="import_dialog.ui" line="26"/>
        <source>Mozc Dictionary Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="75"/>
        <source>File Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="82"/>
        <source>Dictionary Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="89"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="96"/>
        <source>Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="103"/>
        <source>Select file...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dictionary_tool.cc" line="228"/>
        <source>Importing new words...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegisterForm</name>
    <message>
        <location filename="register_form.ui" line="5"/>
        <source>Register Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="13"/>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="23"/>
        <source>Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="33"/>
        <source>Part of speech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="43"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="55"/>
        <source>Register</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.ui" line="62"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.cc" line="254"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="269"/>
        <source>Another process is accessing the user dictionary file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="327"/>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="327"/>
        <source>Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="328"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="361"/>
        <source>New dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1092"/>
        <source>Rename...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1093"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="366"/>
        <source>Import as new dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="368"/>
        <source>Import to current dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="442"/>
        <source>User Dictionary 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="606"/>
        <location filename="dictionary_tool.cc" line="682"/>
        <source>You can&apos;t have more than %1 dictionaries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="611"/>
        <source>Name of the new dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="625"/>
        <location filename="dictionary_tool.cc" line="654"/>
        <location filename="dictionary_tool.cc" line="704"/>
        <location filename="dictionary_tool.cc" line="854"/>
        <location filename="dictionary_tool.cc" line="896"/>
        <source>No dictionary is selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="631"/>
        <source>Do you want to delete %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="660"/>
        <source>New name of the dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1219"/>
        <source>Dictionary name is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1224"/>
        <source>Dictionary name is too long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1214"/>
        <source>An invalid character is included in the dictionary name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="279"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="369"/>
        <source>Export current dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="901"/>
        <source>Export dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="280"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="278"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="328"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="363"/>
        <source>Delete dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="711"/>
        <location filename="dictionary_tool.cc" line="933"/>
        <source>You can&apos;t have more than %1 words in one dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="860"/>
        <source>All user-registered words in %1 are migrated into the current dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="764"/>
        <source>Failed to open user dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="902"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="780"/>
        <location filename="dictionary_tool.cc" line="910"/>
        <source>Can&apos;t open %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="362"/>
        <source>Rename dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="376"/>
        <source>Import from %1&apos;s user dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="488"/>
        <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="568"/>
        <source>Updating the current view data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="735"/>
        <source>%1 entries are imported to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="741"/>
        <source>You have imported a file in an invalid or unsupported file format.

Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="750"/>
        <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="757"/>
        <source>%1 entries are imported to %2.

Some imported words were not recognized by %3. Please check the original import file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="845"/>
        <source>Microsoft IME dictioanry import function doesn&apos;t work on UAC-elevated process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="923"/>
        <source>Dictionary export finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="971"/>
        <source>Do you want to delete this word?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="973"/>
        <source>Do you want to delete the selected words?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="987"/>
        <source>Deleting the selected words...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1024"/>
        <source>An invalid character is included in the reading.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1057"/>
        <source>Add a word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1062"/>
        <source>Delete this word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1069"/>
        <source>Delete the selected words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1094"/>
        <source>Import to this dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1095"/>
        <source>Export this dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1229"/>
        <source>A fatal error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1341"/>
        <source>%1: %2 entries</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ImportDialog</name>
    <message>
        <location filename="import_dialog.cc" line="26"/>
        <location filename="import_dialog.cc" line="55"/>
        <source>Auto detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="29"/>
        <source>Google</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="34"/>
        <location filename="import_dialog.cc" line="50"/>
        <source>Microsoft IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="37"/>
        <location filename="import_dialog.cc" line="47"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="40"/>
        <location filename="import_dialog.cc" line="44"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="58"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="61"/>
        <source>Shift JIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="64"/>
        <source>UTF-8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="69"/>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="161"/>
        <source>Import dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="163"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::RegisterForm</name>
    <message>
        <location filename="register_form.cc" line="36"/>
        <source>Register word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="register_form.cc" line="45"/>
        <source>Modify word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mozc_1.1.773.102.orig.tar.gz: mozc-1.1.773.102/gui/dictionary_tool/dictionary_tool_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.ui" line="14"/>
        <source>Mozc Dictionary Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.ui" line="31"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="import_dialog.ui" line="26"/>
        <source>Mozc Dictionary Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="75"/>
        <source>File Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="82"/>
        <source>Dictionary Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="89"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="96"/>
        <source>Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.ui" line="103"/>
        <source>Select file...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dictionary_tool.cc" line="232"/>
        <source>Importing new words...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::DictionaryTool</name>
    <message>
        <location filename="dictionary_tool.cc" line="258"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="276"/>
        <source>Another process is accessing the user dictionary file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="340"/>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="340"/>
        <source>Word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="341"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="374"/>
        <source>New dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1169"/>
        <source>Rename...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1170"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="379"/>
        <source>Import as new dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="381"/>
        <source>Import to current dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="455"/>
        <source>User Dictionary 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="619"/>
        <location filename="dictionary_tool.cc" line="695"/>
        <source>You can&apos;t have more than %1 dictionaries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="624"/>
        <source>Name of the new dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="638"/>
        <location filename="dictionary_tool.cc" line="667"/>
        <location filename="dictionary_tool.cc" line="717"/>
        <location filename="dictionary_tool.cc" line="867"/>
        <location filename="dictionary_tool.cc" line="909"/>
        <source>No dictionary is selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="644"/>
        <source>Do you want to delete %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="673"/>
        <source>New name of the dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1296"/>
        <source>Dictionary name is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1301"/>
        <source>Dictionary name is too long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1291"/>
        <source>An invalid character is included in the dictionary name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="292"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="382"/>
        <source>Export current dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="914"/>
        <source>Export dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="293"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="291"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="341"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="376"/>
        <source>Delete dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="724"/>
        <location filename="dictionary_tool.cc" line="946"/>
        <source>You can&apos;t have more than %1 words in one dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="873"/>
        <source>All user-registered words in %1 are migrated into the current dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="777"/>
        <source>Failed to open user dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="915"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="793"/>
        <location filename="dictionary_tool.cc" line="923"/>
        <source>Can&apos;t open %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="375"/>
        <source>Rename dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="389"/>
        <source>Import from %1&apos;s user dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="501"/>
        <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="581"/>
        <source>Updating the current view data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="748"/>
        <source>%1 entries are imported to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="754"/>
        <source>You have imported a file in an invalid or unsupported file format.

Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="763"/>
        <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="770"/>
        <source>%1 entries are imported to %2.

Some imported words were not recognized by %3. Please check the original import file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="858"/>
        <source>Microsoft IME dictioanry import function doesn&apos;t work on UAC-elevated process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="936"/>
        <source>Dictionary export finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="984"/>
        <source>Do you want to delete this word?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="986"/>
        <source>Do you want to delete the selected words?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1000"/>
        <source>Deleting the selected words...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1051"/>
        <source>New comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1083"/>
        <source>An invalid character is included in the reading.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1116"/>
        <source>Add a word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1121"/>
        <source>Delete this word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1128"/>
        <source>Delete the selected words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1136"/>
        <source>Change category to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1144"/>
        <source>Edit comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1171"/>
        <source>Import to this dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1172"/>
        <source>Export this dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1306"/>
        <source>Dictionary already exists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1311"/>
        <source>A fatal error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dictionary_tool.cc" line="1423"/>
        <source>%1: %2 entries</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ImportDialog</name>
    <message>
        <location filename="import_dialog.cc" line="26"/>
        <location filename="import_dialog.cc" line="55"/>
        <source>Auto detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="29"/>
        <source>Google</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="34"/>
        <location filename="import_dialog.cc" line="50"/>
        <source>Microsoft IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="37"/>
        <location filename="import_dialog.cc" line="47"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="40"/>
        <location filename="import_dialog.cc" line="44"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="58"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="61"/>
        <source>Shift JIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="64"/>
        <source>UTF-8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="69"/>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="161"/>
        <source>Import dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="import_dialog.cc" line="163"/>
        <source>Text Files (*.txt);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
